# PriceChangeOption


## Enum

* `NOCHANGE` (value: `'NoChange'`)

* `SPECIFICPERCENTAGEVALUE` (value: `'SpecificPercentageValue'`)

* `USELATESTPRODUCTCATALOGPRICING` (value: `'UseLatestProductCatalogPricing'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


